linux-6.18.2-sparky for Debian
-----------------------------

<Possible notes regarding this package - if none, delete this file.>

 -- pavroo <pavroo@onet.eu>  Thu, 18 Dec 2025 18:18:45 +0100
